[Libreoffice-commits] core.git: Branch 'aoo/trunk' - sw/source
Clarence Guo
clarence_guo at apache.org
Wed Jun 25 01:09:51 PDT 2014
sw/source/core/txtnode/thints.cxx | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
New commits:
commit fba2d04a09a2e040f36991f42062a1c5110fea13
Author: Clarence Guo <clarence_guo at apache.org>
Date: Wed Jun 25 06:08:29 2014 +0000
Fix issue 125154
diff --git a/sw/source/core/txtnode/thints.cxx b/sw/source/core/txtnode/thints.cxx
index 66781e0..19fe3e5 100644
--- a/sw/source/core/txtnode/thints.cxx
+++ b/sw/source/core/txtnode/thints.cxx
@@ -1790,10 +1790,10 @@ void SwTxtNode::DelSoftHyph( const xub_StrLen nStt, const xub_StrLen nEnd )
}
//Modify here for #119405, by easyfan, 2012-05-24
//In MS Word, the font underline setting of the paragraph end position wont affect the formatting of numbering, so we ignore it
bool lcl_IsIgnoredCharFmtForNumbering(const sal_uInt16 nWhich)
{
- return (nWhich == RES_CHRATR_UNDERLINE);
+ return (nWhich == RES_CHRATR_UNDERLINE || nWhich == RES_CHRATR_ESCAPEMENT);
}
//In MS Word, following properties of the paragraph end position wont affect the formatting of bullets, so we ignore them:
@@ -1802,7 +1802,7 @@ bool lcl_IsIgnoredCharFmtForNumbering(const sal_uInt16 nWhich)
//Font Bold of Wertern, CJK and CTL;
bool lcl_IsIgnoredCharFmtForBullets(const sal_uInt16 nWhich)
{
- return (nWhich == RES_CHRATR_UNDERLINE || nWhich == RES_CHRATR_POSTURE || nWhich == RES_CHRATR_WEIGHT
+ return (nWhich == RES_CHRATR_UNDERLINE || nWhich == RES_CHRATR_POSTURE || nWhich == RES_CHRATR_WEIGHT
|| nWhich == RES_CHRATR_CJK_POSTURE || nWhich == RES_CHRATR_CJK_WEIGHT
|| nWhich == RES_CHRATR_CTL_POSTURE || nWhich == RES_CHRATR_CTL_WEIGHT);
}
@@ -1790,10 +1790,10 @@ void SwTxtNode::DelSoftHyph( const xub_StrLen nStt, const xub_StrLen nEnd )
}
//Modify here for #119405, by easyfan, 2012-05-24
-//In MS Word, the font underline setting of the paragraph end position wont affect the formatting of numbering, so we ignore it
+//In MS Word, the font underline setting of the paragraph end position wont affect the formatting of numbering, escapement, etc, so we ignore them
bool lcl_IsIgnoredCharFmtForNumbering(const sal_uInt16 nWhich)
{
More information about the Libreoffice-commits
mailing list